Gemeinde Adressverwaltung GUI: Klassen-Verzeichnis

Gemeinde Adressverwaltung GUI

Klassen-Verzeichnis
A | F | G | J | L | M | P | V

A
  Anrede (Gemeinde_Modelle)

F
  Familie (Gemeinde_Modelle)
  FamilieGruppe (Gemeinde_Modelle)
  FamilieGruppeSchlank (Gemeinde_Modelle)
  FamilieVersandart (Gemeinde_Modelle)
  FamilieVersandartSchlank (Gemeinde_Modelle)
  Farbe (Gemeinde_Modelle)

G
  Gemeinde (Gemeinde_Modelle)
  Gruppe (Gemeinde_Modelle)
  GruppeAnsprechpartner (Gemeinde_Modelle)

J
  Jobs (Gemeinde_Modelle)
  JobsSchlank (Gemeinde_Modelle)

L
  Login (Gemeinde)

M
  Main (Gemeinde)

P
  Person (Gemeinde_Modelle)
  PersonGruppe (Gemeinde_Modelle)
  PersonGruppeSchlank (Gemeinde_Modelle)
  PersonSchlank (Gemeinde_Modelle)
  PersonVersandart (Gemeinde_Modelle)
  PersonVersandartSchlank (Gemeinde_Modelle)

V
  Versandart (Gemeinde_Modelle)